@@ -1,7 +1,7 @@
 """
 This library is an implementation of Stakeholder Specific Vulnerability Categorization(SVCC)
 """
-__version__ = "0.0.1"
+__version__ = "0.0.9"
 
 from .helpers import initialize_db, get_db_conn, get_cisa_kevc
-from .initialize import start_script
+from .ssvc_ore import ssvc_recommendations
